@@ -11,30 +11,36 @@ class ContentValidator:
         self,
         client: LookerClient,
         exclude_personal: bool = False,
-        folders: List[str] = None,
+        folders: Optional[List[str]] = None,
     ):
-        include_folders = []
-        exclude_folders = []
+        self.client = client
+        self.exclude_personal = exclude_personal
+        self.include_folders: List[str] = []
+        self.exclude_folders: List[str] = []
+
         if folders:
             for folder_id in folders:
                 if folder_id.startswith("-"):
-                    exclude_folders.append(int(folder_id[1:]))
+                    self.exclude_folders.append(folder_id[1:])
                 else:
-                    include_folders.append(int(folder_id))
+                    self.include_folders.append(folder_id)
 
-        logger.debug(f"Including content in folders: {include_folders}")
-
-        self.client = client
-        personal_folders = self._get_personal_folders() if exclude_personal else []
+    async def validate(self, project: Project) -> List[ContentError]:
+        personal_folders = (
+            await self._get_personal_folders() if self.exclude_personal else []
+        )
 
-        self.excluded_folders: List[int] = personal_folders + (
-            self._get_all_subfolders(exclude_folders) if exclude_folders else []
+        self.excluded_folders: List[str] = personal_folders + (
+            await self._get_all_subfolders(self.exclude_folders)
+            if self.exclude_folders
+            else []
         )
-        self.included_folders: List[int] = (
-            self._get_all_subfolders(include_folders) if include_folders else []
+        self.included_folders: List[str] = (
+            await self._get_all_subfolders(self.include_folders)
+            if self.include_folders
+            else []
         )
 
-    def validate(self, project: Project) -> List[ContentError]:
         def is_folder_selected(folder_id: Optional[str]) -> bool:
             if folder_id in self.excluded_folders:
                 return False
@@ -43,7 +49,7 @@ class ContentValidator:
             else:
                 return True
 
-        result = self.client.content_validation()
+        result = await self.client.content_validation()
         project.queried = True
 
         content_errors: List[ContentError] = []
@@ -52,7 +58,7 @@ class ContentValidator:
             try:
                 content_type = self._get_content_type(content)
             except KeyError:
-                logger.warn(
+                logger.warning(
                     "Warning: Skipping some content because it does not seem to be a "
                     "Dashboard or a Look."
                 )
@@ -71,17 +77,17 @@ class ContentValidator:
 
         return content_errors
 
-    def _get_personal_folders(self) -> List[int]:
+    async def _get_personal_folders(self) -> List[str]:
         personal_folders = []
-        result = self.client.all_folders()
+        result = await self.client.all_folders()
         for folder in result:
             if folder["is_personal"] or folder["is_personal_descendant"]:
                 personal_folders.append(folder["id"])
         return personal_folders
 
-    def _get_all_subfolders(self, input_folders: List[int]) -> List[int]:
+    async def _get_all_subfolders(self, input_folders: List[str]) -> List[str]:
         result = []
-        all_folders = self.client.all_folders()
+        all_folders = await self.client.all_folders()
         for folder_id in input_folders:
             if not any(folder["id"] == folder_id for folder in all_folders):
                 raise SpectaclesException(
@@ -92,7 +98,7 @@ class ContentValidator:
             result.extend(self._get_subfolders(folder_id, all_folders))
         return result
 
-    def _get_subfolders(self, folder_id: int, all_folders: List[JsonDict]) -> List[int]:
+    def _get_subfolders(self, folder_id: str, all_folders: List[JsonDict]) -> List[str]:
         subfolders = [folder_id]
         children = [
             child["id"] for child in all_folders if child["parent_id"] == folder_id
@@ -104,12 +110,24 @@ class ContentValidator:
 
     @staticmethod
     def _get_content_type(content: Dict[str, Any]) -> str:
-        if content["dashboard"]:
-            return "dashboard"
-        elif content["look"]:
-            return "look"
-        else:
-            raise KeyError("Content type not found. Valid keys are 'look', 'dashboard'")
+        CONTENT_TYPES = (
+            "look",
+            "dashboard",
+            "dashboard_element",
+            "dashboard_filter",
+            "scheduled_plan",
+            "alert",
+            "lookml_dashboard",
+            "lookml_dashboard_element",
+        )
+        for content_type in CONTENT_TYPES:
+            if content.get(content_type):
+                return content_type
+
+        # If none of the content types are found
+        raise KeyError(
+            f"Content type not found. Valid keys are: {', '.join(CONTENT_TYPES)}"
+        )
 
     @staticmethod
     def _get_tile_type(content: Dict[str, Any]) -> str:
@@ -137,6 +155,8 @@ class ContentValidator:
             # Skip errors that are not associated with selected explores or existing models
             if explore or model:
                 content_id = result[content_type]["id"]
+                folder = result[content_type].get("folder")
+                folder_name: Optional[str] = folder.get("name") if folder else None
                 content_error = ContentError(
                     model=model_name,
                     explore=explore_name,
@@ -144,7 +164,7 @@ class ContentValidator:
                     field_name=error["field_name"],
                     content_type=content_type,
                     title=result[content_type]["title"],
-                    space=result[content_type]["space"]["name"],
+                    folder=folder_name,
                     url=f"{self.client.base_url}/{content_type}s/{content_id}",
                     tile_type=(
                         self._get_tile_type(result)
